@@ -28,7 +28,9 @@
 #include <QMetaMethod>
 #include <QPixmap>
 #include <QPluginLoader>
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 62)
 #include <QWidget>
+#endif
 #include <QWindow>
 #if KWINDOWSYSTEM_HAVE_X11
 #include <QX11Info>
@@ -153,7 +155,7 @@ void KWindowSystemPrivateDummy::setOnActivities(WId win, const QStringList &acti
     Q_UNUSED(activities)
 }
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 WId KWindowSystemPrivateDummy::transientFor(WId window)
 {
     Q_UNUSED(window)
@@ -377,7 +379,7 @@ QList<WId> KWindowSystem::windows()
     return d->windows();
 }
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 KWindowInfo KWindowSystem::windowInfo(WId win, NET::Properties properties, NET::Properties2 properties2)
 {
     return KWindowInfo(win, properties, properties2);
@@ -455,13 +457,12 @@ void KWindowSystem::demandAttention(WId win, bool set)
     d->demandAttention(win, set);
 }
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 WId KWindowSystem::transientFor(WId win)
 {
     Q_D(KWindowSystem);
     return d->transientFor(win);
 }
-#endif
 
 void KWindowSystem::setMainWindow(QWidget *subWidget, WId mainWindowId)
 {
@@ -470,18 +471,22 @@ void KWindowSystem::setMainWindow(QWidget *subWidget, WId mainWindowId)
     subWidget->setAttribute(Qt::WA_NativeWindow, true);
     QWindow *subWindow = subWidget->windowHandle();
     Q_ASSERT(subWindow);
+    setMainWindow(subWindow, mainWindowId);
+}
+#endif
 
+void KWindowSystem::setMainWindow(QWindow *subWindow, WId mainWindowId)
+{
     QWindow *mainWindow = QWindow::fromWinId(mainWindowId);
-    if (!mainWindow) {
-        // foreign windows not supported on all platforms
-        return;
+    if (mainWindow) { // foreign windows not supported on all platforms
+        subWindow->setTransientParent(mainWindow);
+
+        // mainWindow is not the child of any object, so make sure it gets deleted at some point
+        connect(subWindow, &QObject::destroyed, mainWindow, &QObject::deleteLater);
     }
-    // mainWindow is not the child of any object, so make sure it gets deleted at some point
-    connect(subWidget, &QObject::destroyed, mainWindow, &QObject::deleteLater);
-    subWindow->setTransientParent(mainWindow);
 }
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 WId KWindowSystem::groupLeader(WId win)
 {
     Q_D(KWindowSystem);
@@ -559,7 +564,7 @@ void KWindowSystem::unminimizeWindow(WId win)
     d->unminimizeWindow(win);
 }
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 void KWindowSystem::minimizeWindow(WId win, bool animation)
 {
     Q_UNUSED(animation)
@@ -567,7 +572,7 @@ void KWindowSystem::minimizeWindow(WId win, bool animation)
 }
 #endif
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 void KWindowSystem::unminimizeWindow(WId win, bool animation)
 {
     Q_UNUSED(animation)
