@@ -103,7 +103,7 @@ static OSStatus applicationEventHandler(EventHandlerCallRef inHandlerCallRef, Ev
 
     kind = GetEventKind(inEvent);
     ProcessSerialNumber psn;
-    if (GetEventParameter(inEvent, kEventParamProcessID, typeProcessSerialNumber, NULL, sizeof psn, NULL, &psn) != noErr) {
+    if (GetEventParameter(inEvent, kEventParamProcessID, typeProcessSerialNumber, nullptr, sizeof psn, nullptr, &psn) != noErr) {
         kWarning() << "Error getting event parameter in application event";
         return eventNotHandledErr;
     }
@@ -338,7 +338,7 @@ bool KWindowSystem::hasWId(WId id)
     return d->windows.contains(id);
 }
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 0)
 KWindowInfo KWindowSystem::windowInfo(WId win, unsigned long properties, unsigned long properties2)
 {
     KWindowSystemPrivate *d = KWindowSystem::s_d_func();
