@@ -27,14 +27,13 @@ DEALINGS IN THE SOFTWARE.
 #include <config-kwindowsystem.h>
 #include "kwindowsystem.h"
 
-#include <QtCore/QBasicTimer>
+#include <QBasicTimer>
 #include <QDebug>
 #include <QGuiApplication>
 #include <QTimerEvent>
 #include <QAbstractNativeEventFilter>
 
 #include <qx11info_x11.h>
-#include <qwidget.h>
 
 static xcb_window_t get_selection_owner(xcb_connection_t *c, xcb_atom_t selection)
 {
@@ -109,7 +108,7 @@ public:
     static Private *create(KSelectionOwner *owner, const char *selection_P, xcb_connection_t *c, xcb_window_t root);
 
 protected:
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) Q_DECL_OVERRIDE {
+    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override {
         Q_UNUSED(result);
         if (eventType != "xcb_generic_event_t")
         {
