@@ -19,6 +19,7 @@
 #include "kwindoweffects_x11.h"
 
 #include <QVarLengthArray>
+#include <QGuiApplication>
 
 #include "kwindowsystem.h"
 #include <config-kwindowsystem.h>
@@ -26,9 +27,7 @@
 #include <xcb/xcb.h>
 #include <QX11Info>
 #include <QMatrix4x4>
-#include <QWidget>
 
-static const char DASHBOARD_WIN_CLASS[] = "dashboard\0dashboard";
 using namespace KWindowEffects;
 
 KWindowEffectsPrivateX11::KWindowEffectsPrivateX11()
@@ -62,10 +61,12 @@ bool KWindowEffectsPrivateX11::isEffectAvailable(Effect effect)
     case BlurBehind:
         effectName = QByteArrayLiteral("_KDE_NET_WM_BLUR_BEHIND_REGION");
         break;
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 67)
     case Dashboard:
         // TODO: Better namespacing for atoms
         effectName = QByteArrayLiteral("_WM_EFFECT_KDE_DASHBOARD");
         break;
+#endif
     case BackgroundContrast:
         effectName = QByteArrayLiteral("_KDE_NET_WM_BACKGROUND_CONTRAST_REGION");
         break;
@@ -134,15 +135,10 @@ void KWindowEffectsPrivateX11::slideWindow(WId id, SlideFromLocation location, i
     }
 }
 
-void KWindowEffectsPrivateX11::slideWindow(QWidget *widget, SlideFromLocation location)
-{
-    slideWindow(widget->effectiveWinId(), location, -1);
-}
-
 QList<QSize> KWindowEffectsPrivateX11::windowSizes(const QList<WId> &ids)
 {
     QList<QSize> windowSizes;
-    Q_FOREACH (WId id, ids) {
+    for (WId id : ids) {
         if (id > 0) {
             KWindowInfo info(id, NET::WMGeometry | NET::WMFrameExtents);
             windowSizes.append(info.frameGeometry().size());
@@ -256,11 +252,12 @@ void KWindowEffectsPrivateX11::enableBlurBehind(WId window, bool enable, const Q
     }
 
     if (enable) {
-        QVector<QRect> rects = region.rects();
         QVector<uint32_t> data;
-        data.reserve(rects.count() * 4);
-        Q_FOREACH (const QRect &r, rects) {
-            data << r.x() << r.y() << r.width() << r.height();
+        data.reserve(region.rectCount() * 4);
+        for (const QRect& r : region) {
+            // kwin on X uses device pixels, convert from logical
+            auto dpr = qApp->devicePixelRatio();
+            data << r.x() * dpr << r.y() * dpr << r.width() * dpr << r.height() * dpr;
         }
 
         xcb_change_property(c, XCB_PROP_MODE_REPLACE, window, atom->atom, XCB_ATOM_CARDINAL,
@@ -281,11 +278,11 @@ void KWindowEffectsPrivateX11::enableBackgroundContrast(WId window, bool enable,
     }
 
     if (enable) {
-        QVector<QRect> rects = region.rects();
         QVector<uint32_t> data;
-        data.reserve(rects.count() * 4 + 16);
-        Q_FOREACH (const QRect &r, rects) {
-            data << r.x() << r.y() << r.width() << r.height();
+        data.reserve(region.rectCount() * 4 + 16);
+        for (const QRect& r : region) {
+            auto dpr = qApp->devicePixelRatio();
+            data << r.x() * dpr << r.y() * dpr << r.width() * dpr << r.height() * dpr;
         }
 
         QMatrix4x4 satMatrix; //saturation
@@ -320,7 +317,6 @@ void KWindowEffectsPrivateX11::enableBackgroundContrast(WId window, bool enable,
         }
 
         QMatrix4x4 colorMatrix = contMatrix * satMatrix * intMatrix;
-        colorMatrix = colorMatrix;
         colorMatrix = colorMatrix.transposed();
 
         uint32_t *rawData = reinterpret_cast<uint32_t *>(colorMatrix.data());
@@ -336,8 +332,10 @@ void KWindowEffectsPrivateX11::enableBackgroundContrast(WId window, bool enable,
     }
 }
 
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 67)
 void KWindowEffectsPrivateX11::markAsDashboard(WId window)
 {
+    static const char DASHBOARD_WIN_CLASS[] = "dashboard\0dashboard";
     xcb_connection_t *c = QX11Info::connection();
     if (!c) {
         return;
@@ -345,4 +343,4 @@ void KWindowEffectsPrivateX11::markAsDashboard(WId window)
     xcb_change_property(c, XCB_PROP_MODE_REPLACE, window, XCB_ATOM_WM_CLASS,
                         XCB_ATOM_STRING, 8, 19, DASHBOARD_WIN_CLASS);
 }
-
+#endif
