@@ -30,6 +30,7 @@
 #include <stdio.h>
 
 #include <QByteArray>
+#include <QString>
 
 class KXErrorHandlerPrivate
 {
@@ -141,8 +142,8 @@ QByteArray KXErrorHandler::errorMessage(const XErrorEvent &event, Display *dpy)
     // "Error: <error> (<value>), Request: <request>(<value>), Resource: <value>"
     QByteArray ret;
     char tmp[ 256 ];
-    char num[ 256 ];
 #if 0 // see below
+    char num[ 256 ];
     if (event.request_code < 128)  // core request
 #endif
     {
@@ -151,6 +152,7 @@ QByteArray KXErrorHandler::errorMessage(const XErrorEvent &event, Display *dpy)
             *paren = '\0';    // it more verbose and is not really useful
         }
         // the various casts are to get overloads non-ambiguous :-/
+/*
         ret = QByteArray("error: ") + (const char *)tmp + '[' + QByteArray::number(event.error_code) + ']';
         sprintf(num, "%d", event.request_code);
         XGetErrorDatabaseText(dpy, "XRequest", num, "<unknown>", tmp, 256);
@@ -158,6 +160,7 @@ QByteArray KXErrorHandler::errorMessage(const XErrorEvent &event, Display *dpy)
         if (event.resourceid != 0) {
             ret += QByteArray(", resource: 0x") + QByteArray::number((qlonglong)event.resourceid, 16);
         }
+*/
     }
 #if 0
     else { // extensions
@@ -173,9 +176,9 @@ QByteArray KXErrorHandler::errorMessage(const XErrorEvent &event, Display *dpy)
         Display *dpy2 = XOpenDisplay(XDisplayString(dpy));
         int nextensions;
         char **extensions = XListExtensions(dpy2, &nextensions);
-        int *majors = NULL;
-        int *error_bases = NULL;
-        if (extensions == NULL) {
+        int *majors = nullptr;
+        int *error_bases = nullptr;
+        if (extensions == nullptr) {
             nextensions = 0;
         } else {
             majors = new int[ nextensions ];
@@ -235,7 +238,7 @@ QByteArray KXErrorHandler::errorMessage(const XErrorEvent &event, Display *dpy)
         if (event.resourceid != 0) {
             ret += QByteArray(", resource: 0x") + QByteArray::number((qlonglong)event.resourceid, 16);
         }
-        if (extensions != NULL) {
+        if (extensions != nullptr) {
             XFreeExtensionList(extensions);
         }
         delete[] majors;
